@@ -1,4 +1,4 @@
-/* $Id: sample-plug-in.c,v 1.1 2000/01/15 05:18:50 trow Exp $ */
+/* $Id: sample-plug-in.c,v 1.2 2000/02/11 19:45:52 trow Exp $ */
 
 /*
  * sample-plug-in.c
@@ -27,37 +27,26 @@
 #include <config.h>
 #include <gnome.h>
 
-#include <guppi-plot-plug-in.h>
+#include <guppi-plug-in.h>
 
-GuppiPlotElement*
-make_element(void)
+GuppiPlugIn* guppi_plug_in(void);
+
+GuppiPlugIn*
+guppi_plug_in(void)
 {
-  return NULL;
+  GuppiPlugIn* pi = guppi_plug_in_new();
+
+  pi->magic_number = GUPPI_PLUG_IN_MAGIC_NUMBER;
+  pi->type = "sample";
+  pi->external_name = _("Sample Plug-In");
+  pi->internal_name = "sample";
+  pi->major_version = 3;
+  pi->minor_version = 14;
+  pi->micro_version = 159;
+  pi->copyright = "(C) 2000 The Gratis Software Foundation";
+  pi->authors = "A. Programmer <aprog@gsf.org>";
+
+  return pi;
 }
 
-static GuppiPlotPlugInInfo info = {
-  GUPPI_PLOT_PLUG_IN_MAGIC_NUMBER,
-  N_("sample"),
-  "sample",
-  0,
-  0,
-  1,
-  "Copyright (C) 2000 EMC Capital Management, Inc.",
-  "Jon Trowbridge",
-  make_element,
-  NULL
-};
-
-
-GuppiPlotPlugInInfo*
-plot_plug_in(void)
-{
-  /* Do any other necessary initialization here. */
-  return &info;
-}
-
-
-
-
-
-/* $Id: sample-plug-in.c,v 1.1 2000/01/15 05:18:50 trow Exp $ */
+/* $Id: sample-plug-in.c,v 1.2 2000/02/11 19:45:52 trow Exp $ */
