@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-scatter-state-control.c,v 1.4 2000/02/09 19:41:51 trow Exp $ */
+/* $Id: guppi-scatter-state-control.c,v 1.5 2000/02/23 21:13:40 trow Exp $ */
 
 /*
  * guppi-scatter-state-control.c
@@ -130,7 +130,7 @@ guppi_scatter_state_control_apply_state(GuppiScatterStateControl* gssc)
   guppi_data_picker_set_selected_data(GUPPI_DATA_PICKER(y_picker),
 				      (GuppiData*)state->y_data);
 
-  gtk_widget_set_sensitive(gssc->style_control, can_plot);
+  gtk_widget_set_sensitive(gssc->notebook, can_plot);
 }
 
 static void
@@ -193,6 +193,11 @@ guppi_scatter_state_control_construct(GuppiScatterStateControl* gssc,
 {
   gchar* path;
   GtkWidget* w;
+  GtkWidget* stycont;
+  GtkNotebook* nb;
+  GtkWidget* label;
+  gchar buffer[256];
+  gint i;
 
   g_return_if_fail(gssc != NULL);
   g_return_if_fail(state != NULL);
@@ -210,17 +215,24 @@ guppi_scatter_state_control_construct(GuppiScatterStateControl* gssc,
   gssc->widget = glade_xml_get_widget(gssc->glade_xml, "root_table");
 
   /* A crude hack */
-  gssc->style_control = guppi_scatter_style_control_new(guppi_scatter_state_get_style(gssc->state, 0));
+  nb = GTK_NOTEBOOK(gtk_notebook_new());
+  gssc->notebook = GTK_WIDGET(nb);
+  gtk_notebook_set_tab_pos(nb, GTK_POS_BOTTOM);
 
   /* Manually add our style control */
   w = glade_xml_get_widget(gssc->glade_xml, "style_frame");
-  gtk_container_add(GTK_CONTAINER(w), gssc->style_control);
-  gtk_widget_show(gssc->style_control);
-  
+  gtk_container_add(GTK_CONTAINER(w), gssc->notebook);
+  for (i=0; i<8; ++i) {
+    stycont = guppi_scatter_style_control_new(guppi_scatter_state_get_style(gssc->state, i));
+    g_snprintf(buffer, 256, "Style %d", i+1);
+    label = gtk_label_new(buffer);
+    gtk_notebook_append_page(nb, stycont, label);
+  }
+	
   guppi_scatter_state_control_apply_state(gssc);
   guppi_scatter_state_control_connect_signals(gssc);
 
-  gtk_widget_show(gssc->widget);
+  gtk_widget_show_all(gssc->widget);
   gtk_container_add(GTK_CONTAINER(gssc), gssc->widget);
 }
 
@@ -240,4 +252,4 @@ guppi_scatter_state_control_new(GuppiScatterState* state)
 
 
 
-/* $Id: guppi-scatter-state-control.c,v 1.4 2000/02/09 19:41:51 trow Exp $ */
+/* $Id: guppi-scatter-state-control.c,v 1.5 2000/02/23 21:13:40 trow Exp $ */
