@@ -1,4 +1,4 @@
-/* $Id: guppi-scatter-state.c,v 1.6 2000/02/21 18:34:22 trow Exp $ */
+/* $Id: guppi-scatter-state.c,v 1.8 2000/02/28 05:07:13 trow Exp $ */
 
 /*
  * guppi-scatter-state.c
@@ -348,7 +348,7 @@ guppi_scatter_state_brush_rectangle(GuppiScatterState* ss,
 void
 guppi_scatter_state_brush_circle(GuppiScatterState* ss,
 				 gint brush_number,
-				 double x, double y, gint r,
+				 double x, double y, double r,
 				 double x_scale,
 				 double y_scale)
 {
@@ -369,10 +369,10 @@ guppi_scatter_state_brush_circle(GuppiScatterState* ss,
 					       x+r*x_scale);
 
   if (hits) {
-    hits = guppi_seq_scalar_in_place_range_query(ss->y_data,
-						 bd,
-						 y-r*y_scale,
-						 y+r*y_scale);
+    hits = guppi_seq_scalar_bitwise_and_range_query(ss->y_data,
+						    bd,
+						    y-r*y_scale,
+						    y+r*y_scale);
   }
 
   if (hits) {
@@ -398,4 +398,4 @@ guppi_scatter_state_brush_circle(GuppiScatterState* ss,
 
 				    
 
-/* $Id: guppi-scatter-state.c,v 1.6 2000/02/21 18:34:22 trow Exp $ */
+/* $Id: guppi-scatter-state.c,v 1.8 2000/02/28 05:07:13 trow Exp $ */
