@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-scatter-style.c,v 1.11 2000/02/11 19:45:11 trow Exp $ */
+/* $Id: guppi-scatter-style.c,v 1.12 2000/02/28 05:07:34 trow Exp $ */
 
 /*
  * guppi-scatter-style.c
@@ -29,10 +29,6 @@
 #include <math.h>
 #include <guppi-rgb.h>
 #include "guppi-scatter-style.h"
-#ifdef BENCH
-#include <sys/time.h>
-#include <unistd.h>
-#endif
 
 const GuppiScatterMarkerInfo
 guppi_scatter_marker_info[SCATTER_MARKER_LAST_MARKER] = {
@@ -109,7 +105,7 @@ string2scatter_marker(const gchar* s)
   return SCATTER_MARKER_NONE;
 }
 
-AlphaTemplate*
+GuppiAlphaTemplate*
 guppi_scatter_marker_make_alpha_template(GuppiScatterMarker m,
 					 double sz1, double sz2,
 					 double scale_factor)
@@ -126,23 +122,23 @@ guppi_scatter_marker_make_alpha_template(GuppiScatterMarker m,
   case SCATTER_MARKER_ALPHA_TEMPLATE:
     return NULL;
   case SCATTER_MARKER_CIRCLE:
-    return alpha_template_new_ring(sz1, sz2);
+    return guppi_alpha_template_new_ring(sz1, sz2);
   case SCATTER_MARKER_SQUARE:
-    return alpha_template_new_rectangle(sz1, sz2, 0);
+    return guppi_alpha_template_new_rectangle(sz1, sz2, 0);
   case SCATTER_MARKER_DIAMOND:
-    return alpha_template_new_rectangle(sz1, sz2, M_PI/4);
+    return guppi_alpha_template_new_rectangle(sz1, sz2, M_PI/4);
   case SCATTER_MARKER_CROSS:
-    return alpha_template_new_cross(sz1, sz2, 0);
+    return guppi_alpha_template_new_cross(sz1, sz2, 0);
   case SCATTER_MARKER_X:
-    return alpha_template_new_cross(sz1, sz2, M_PI/4);
+    return guppi_alpha_template_new_cross(sz1, sz2, M_PI/4);
   case SCATTER_MARKER_AST:
-    return alpha_template_new_ast(sz1, sz2, 0);
+    return guppi_alpha_template_new_ast(sz1, sz2, 0);
   case SCATTER_MARKER_FILLED_CIRCLE:
-    return alpha_template_new_circle(sz1);
+    return guppi_alpha_template_new_circle(sz1);
   case SCATTER_MARKER_FILLED_SQUARE:
-    return alpha_template_new_box(sz1, 0);
+    return guppi_alpha_template_new_box(sz1, 0);
   case SCATTER_MARKER_FILLED_DIAMOND:
-    return alpha_template_new_box(sz1, M_PI/4);
+    return guppi_alpha_template_new_box(sz1, M_PI/4);
   default:
     g_assert_not_reached();
     return NULL;
@@ -197,8 +193,12 @@ guppi_scatter_style_finalize(GtkObject* obj)
 {
   GuppiScatterStyle* sty = GUPPI_SCATTER_STYLE(obj);
 
-  alpha_template_free(sty->alpha_template);
-  
+  if (sty->alpha_template)
+    gtk_object_unref(GTK_OBJECT(sty->alpha_template));
+
+  if (sty->last_alpha_template)
+    gtk_object_unref(GTK_OBJECT(sty->last_alpha_template));
+
   if (sty->gradient_data)
     gtk_object_unref(GTK_OBJECT(sty->gradient_data));
 
@@ -208,8 +208,6 @@ guppi_scatter_style_finalize(GtkObject* obj)
   if (sty->size2_data)
     gtk_object_unref(GTK_OBJECT(sty->size2_data));
 
-  alpha_template_free(sty->last_alpha_template);
-
   if (parent_class->finalize)
     parent_class->finalize(obj);
 }
@@ -385,7 +383,7 @@ guppi_scatter_style_set_marker(GuppiScatterStyle* sty, GuppiScatterMarker m)
 
     /* Remove our cached alpha template */
     if (sty->last_alpha_template != NULL) {
-      alpha_template_free(sty->last_alpha_template);
+      gtk_object_unref(GTK_OBJECT(sty->last_alpha_template));
       sty->last_alpha_template = NULL;
     }
 
@@ -409,7 +407,7 @@ guppi_scatter_style_set_marker_size1(GuppiScatterStyle* sty, double x)
 
     /* Remove our cached alpha template */
     if (sty->last_alpha_template != NULL) {
-      alpha_template_free(sty->last_alpha_template);
+      gtk_object_unref(GTK_OBJECT(sty->last_alpha_template));
       sty->last_alpha_template = NULL;
     }
 
@@ -433,7 +431,7 @@ guppi_scatter_style_set_marker_size2(GuppiScatterStyle* sty, double x)
 
     /* Remove our cached alpha template */
     if (sty->last_alpha_template != NULL) {
-      alpha_template_free(sty->last_alpha_template);
+      gtk_object_unref(GTK_OBJECT(sty->last_alpha_template));
       sty->last_alpha_template = NULL;
     }
 
@@ -483,13 +481,16 @@ guppi_scatter_style_set_marker_sizes_default(GuppiScatterStyle* sty)
 }
 
 void
-guppi_scatter_style_set_alpha_template(GuppiScatterStyle* sty, AlphaTemplate* atemp)
+guppi_scatter_style_set_alpha_template(GuppiScatterStyle* sty,
+				       GuppiAlphaTemplate* atemp)
 {
   g_return_if_fail(sty != NULL);
   g_return_if_fail(atemp != NULL);
 
-  g_free(sty->alpha_template);
+  if (sty->alpha_template)
+    gtk_object_unref(GTK_OBJECT(sty->alpha_template));
   sty->alpha_template = atemp;
+  gtk_object_ref(GTK_OBJECT(sty->alpha_template));
 
   /* automatically change marker as well */
   sty->marker = SCATTER_MARKER_ALPHA_TEMPLATE;
@@ -675,11 +676,6 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
 			  const GuppiSeqBoolean* mask,
 			  double scale_factor)
 {
-#ifdef BENCH
-  static double t=0;
-  struct timeval time0, time1;
-  static guint point_count=0;
-#endif
   gint r,g,b,a;
 
   gboolean do_gradient_coloring;
@@ -691,8 +687,7 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
   double size1_grad_min=0, size1_grad_max=1, size1_now;
   double size2_grad_min=0, size2_grad_max=1, size2_now;
 
-  AlphaTemplate* atemp = NULL;
-  gboolean temporary_atemp = FALSE;
+  GuppiAlphaTemplate* atemp = NULL;
   
   gint x, y;
   gint xtweak=0, ytweak=0;
@@ -748,30 +743,35 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
       do_size2_gradient = FALSE;
   }
 
-  if (sty->marker == SCATTER_MARKER_ALPHA_TEMPLATE ||
+  if (sty->marker == SCATTER_MARKER_ALPHA_TEMPLATE || 
       sty->alpha_template != NULL) {
+
     atemp = sty->alpha_template;
-    temporary_atemp = FALSE;
+    gtk_object_ref(GTK_OBJECT(atemp));
+
   } else if (sty->last_scale == scale_factor &&
 	     sty->last_alpha_template != NULL) {
+
     atemp = sty->last_alpha_template;
-    temporary_atemp = FALSE;
+    gtk_object_ref(GTK_OBJECT(atemp));
+
   } else if (!do_size1_gradient && !do_size2_gradient) {
+
     atemp = guppi_scatter_marker_make_alpha_template(sty->marker,
 						     sty->size1, sty->size2,
 						     scale_factor);
-    alpha_template_free(sty->last_alpha_template);
+    gtk_object_ref(GTK_OBJECT(atemp));
+
+    if (sty->last_alpha_template) {
+      gtk_object_unref(GTK_OBJECT(sty->last_alpha_template));
+    }
     sty->last_alpha_template = atemp;
+
     sty->last_scale = scale_factor;
-    temporary_atemp = FALSE;
   }
 
   /*** Our actual drawing loop ***/
 
-#ifdef BENCH
-  gettimeofday(&time0, NULL);
-#endif
-    
   if (mask != NULL) 
     k = guppi_seq_boolean_first_true(mask);
   else
@@ -816,28 +816,14 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
     }
 
     if (do_size1_gradient || do_size2_gradient) {
-      /* Right now size-gradients don't scale well, since we need to
-	 rebuild an alpha template for every point.
 
-	 If we are just doing one size gradient, the right thing to do
-	 is to buffer N templates and then just use the one that is
-	 closest to size*_now.  N could be chosen so as to minimize the
-	 maximum possible error between size*_now and the size* of the
-	 buffered template.
-	 
-	 We could do something like this for two size gradients,
-	 buffering NxM templates.  That just seems like it has the
-	 potential to get annoying.  But in reality, it probably wouldn't
-	 be any more annoying that the 1d case.
-      */
-
-      if (temporary_atemp)
-	alpha_template_free(atemp);
+      if (atemp)
+	gtk_object_unref(GTK_OBJECT(atemp));
       atemp = guppi_scatter_marker_make_alpha_template(sty->marker,
 						       size1_now,
 						       size2_now,
 						       scale_factor);
-      temporary_atemp = TRUE;
+      gtk_object_ref(GTK_OBJECT(atemp));
     }
 
     if (atemp) {
@@ -850,10 +836,9 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
 
     if (atemp) {
 
-      /* This is cut&pasted from alpha_template_print(), so we don't have
-	 any function-call overhead.  This should speed things up a little,
-	 maybe a lot. */
-
+      /* This is cut&pasted from guppi_alpha_template_print(), so we don't
+	 have any function-call overhead.  This should speed things up a
+	 little, maybe a lot. */
       x -= adj_x;
       y -= adj_y;
 
@@ -879,6 +864,7 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
 	  atpr_arun = atpr_ap;
 	  atpr_rgbrun = atpr_rgbp;
 	  for (atpr_i=atpr_x0; atpr_i<=atpr_x1; ++atpr_i) {
+
 	    if (*atpr_arun > 0) {
 	      PIXEL_RGBA(atpr_rgbrun, rnow, gnow, bnow,
 			 (((1+anow) * (1+*atpr_arun)) >> 8));
@@ -899,25 +885,14 @@ guppi_scatter_style_paint(GuppiScatterStyle* sty,
     else
       ++k;
 
-#ifdef BENCH
-    ++point_count;
-#endif
-
   }
 
-#ifdef BENCH
-  gettimeofday(&time1, NULL);
-  t += time1.tv_sec - time0.tv_sec + (time1.tv_usec - time0.tv_usec)/1e+6;
-  g_message("time=%f pts=%d pts/sec=%f", t, point_count, point_count/t);
-#endif
-
-
   /*** Clean-up ***/
 
-  if (temporary_atemp)
-    alpha_template_free(atemp);
+  if (atemp) {
+    gtk_object_unref(GTK_OBJECT(atemp));
+    atemp = NULL;
+  }
 }
 									      
-				  
-
-/* $Id: guppi-scatter-style.c,v 1.11 2000/02/11 19:45:11 trow Exp $ */
+/* $Id: guppi-scatter-style.c,v 1.12 2000/02/28 05:07:34 trow Exp $ */
