@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-scatter-style.h,v 1.6 2000/02/09 19:41:51 trow Exp $ */
+/* $Id: guppi-scatter-style.h,v 1.7 2000/02/28 05:07:34 trow Exp $ */
 
 /*
  * guppi-scatter-style.h
@@ -33,7 +33,7 @@
 #include "transform.h"
 #include <guppi-seq-scalar.h>
 #include <guppi-seq-boolean.h>
-#include "alpha-template.h"
+#include <guppi-alpha-template.h>
 
 typedef enum _GuppiScatterMarker GuppiScatterMarker;
 typedef struct _GuppiScatterMarkerInfo GuppiScatterMarkerInfo;
@@ -69,7 +69,7 @@ const GuppiScatterMarkerInfo guppi_scatter_marker_info[SCATTER_MARKER_LAST_MARKE
 
 GuppiScatterMarker string2scatter_marker(const gchar* s);
 
-AlphaTemplate* guppi_scatter_marker_make_alpha_template(GuppiScatterMarker m,
+GuppiAlphaTemplate* guppi_scatter_marker_make_alpha_template(GuppiScatterMarker m,
 							double sz1, double sz2,
 							double scale_factor);
 
@@ -83,7 +83,7 @@ struct _GuppiScatterStyle {
 
   GuppiScatterMarker marker;
   gdouble size1, size2;
-  AlphaTemplate* alpha_template;
+  GuppiAlphaTemplate* alpha_template;
   guint32 color;
 
   const GuppiSeqScalar* gradient_data;
@@ -102,7 +102,7 @@ struct _GuppiScatterStyle {
   gboolean pending_change;
 
   /* Cache for recently used templates */
-  AlphaTemplate* last_alpha_template;
+  GuppiAlphaTemplate* last_alpha_template;
   double last_scale;
 };
 
@@ -133,7 +133,8 @@ void guppi_scatter_style_set_marker_size1(GuppiScatterStyle*, double);
 void guppi_scatter_style_set_marker_size2(GuppiScatterStyle*, double);
 void guppi_scatter_style_set_marker_sizes(GuppiScatterStyle*, double, double);
 void guppi_scatter_style_set_marker_sizes_default(GuppiScatterStyle*);
-void guppi_scatter_style_set_alpha_template(GuppiScatterStyle*, AlphaTemplate*);
+void guppi_scatter_style_set_alpha_template(GuppiScatterStyle*,
+					    GuppiAlphaTemplate*);
 void guppi_scatter_style_set_color(GuppiScatterStyle*, guint32);
 void guppi_scatter_style_set_gradient_data(GuppiScatterStyle*, GuppiSeqScalar*);
 void guppi_scatter_style_set_color_low(GuppiScatterStyle*, guint32);
@@ -172,4 +173,4 @@ void guppi_scatter_style_paint(GuppiScatterStyle*,
 
 #endif /* _INC_GUPPI_SCATTER_STYLE_H */
 
-/* $Id: guppi-scatter-style.h,v 1.6 2000/02/09 19:41:51 trow Exp $ */
+/* $Id: guppi-scatter-style.h,v 1.7 2000/02/28 05:07:34 trow Exp $ */
