@@ -1,4 +1,4 @@
-/* $Id: guppi.c,v 1.11 2000/01/21 06:12:48 trow Exp $ */
+/* $Id: guppi.c,v 1.16 2000/02/21 18:35:01 trow Exp $ */
 
 /*
  * guppi.c
@@ -29,14 +29,16 @@
 #include <glade/glade.h>
 #include <signal.h>
 #include <time.h>
-#include <guppi-data-catalog-browser.h>
+#include <guppi-data-tree-view.h>
 #include "corba_guppi.h"
 #include <guppi-useful.h>
 #include <guppi-data-init.h>
+#include <guppi-plot-init.h>
 #include <guppi-plot-plug-in.h>
 #include "app_scm.h"
 #include "term.h"
 #include "file-open.h"
+#include "plug-ins.h"
 #include "guile-load.h"
 #include "guppi.h"
 
@@ -127,7 +129,7 @@ guile_terminal_cb(GtkWidget* w, gpointer data)
 static void
 hacked_scatter_plot_cb(GtkWidget* w, gpointer data)
 {
-  guppi_eval_str("(let ((s (make-scatter-state))) (edit-scatter-state s) (view-scatter-state s))");
+  guppi_eval_str("(let ((s (guppi-plot-element-new \"scatter\")) (state (guppi-plot-state-new))) (guppi-plot-state-add-element state s) (guppi-plot-state-view state) (guppi-plot-element-edit s))");
 }
 
 static void
@@ -172,6 +174,12 @@ about_cb(GtkWidget* w, gpointer data)
   }
 }
 
+static void
+about_plug_in_cb(GtkWidget* w, gpointer data)
+{
+  loaded_plug_ins();
+}
+
 static GtkWidget*
 guppi_main_window()
 {
@@ -215,6 +223,11 @@ guppi_main_window()
   static GnomeUIInfo help_menu[] = {
     GNOMEUIINFO_HELP("guppi"),
     GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
+    { GNOME_APP_UI_ITEM,
+      N_("About Plug-Ins"), N_("Find Out About Currently Loaded Plug-Ins"),
+      about_plug_in_cb, NULL, NULL,
+      GNOME_APP_PIXMAP_NONE, NULL,
+      0, (GdkModifierType)0, NULL},
     GNOMEUIINFO_END
   };
 
@@ -251,7 +264,7 @@ guppi_main_window()
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin),
 				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-  browser = guppi_data_catalog_browser_new(NULL); /* use default catalog */
+  browser = guppi_data_tree_view_new(guppi_data_tree_main());
   gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(swin), browser);
 
   gnome_app_set_contents(GNOME_APP(app), swin);
@@ -347,11 +360,14 @@ real_main(void* closure, int argc, char* argv[])
   guppi_splash_message(_("Initializing Data Library"));
   guppi_data_init();
 
+  guppi_splash_message(_("Initializing Plot Library"));
+  guppi_plot_init();
+
   guppi_splash_message(_("Initializing GuppiAppGuile"));
   guppi_app_scm_init();
 
   guppi_splash_message(_("Loading Plug-Ins"));
-  guppi_load_all_plug_ins();
+  guppi_plug_in_load_all();
 
   guppi_splash_message(_("Building Main Guppi Window"));
   guppi_app = GNOME_APP(guppi_main_window());
@@ -385,4 +401,4 @@ main(int argc, char* argv[])
 }
 
 
-/* $Id: guppi.c,v 1.11 2000/01/21 06:12:48 trow Exp $ */
+/* $Id: guppi.c,v 1.16 2000/02/21 18:35:01 trow Exp $ */
