@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-seq-boolean-core-impl.c,v 1.2 2000/02/21 18:31:53 trow Exp $ */
+/* $Id: guppi-seq-boolean-core-impl.c,v 1.3 2000/02/23 19:01:43 trow Exp $ */
 
 /*
  * guppi-seq-boolean-core-impl.c
@@ -324,7 +324,7 @@ v_seq_boolean_next_true(const GuppiSeqBooleanImpl* impl, gint i)
   k = i & 31;
   ++i;
   /* Check of our first guint32 */
-  if ((q = (data[j] >> (k+1)))) {
+  if (k != 31 && (q = (data[j] >> (k+1)))) {
     while (!(q&1)) {
       q = q>>1;
       ++i;
@@ -655,4 +655,4 @@ guppi_seq_boolean_core_impl_new(void)
 
 
 
-/* $Id: guppi-seq-boolean-core-impl.c,v 1.2 2000/02/21 18:31:53 trow Exp $ */
+/* $Id: guppi-seq-boolean-core-impl.c,v 1.3 2000/02/23 19:01:43 trow Exp $ */
