@@ -1,4 +1,4 @@
-/* $Id: guppi-canvas-item.c,v 1.7 2000/02/10 02:05:31 trow Exp $ */
+/* $Id: guppi-canvas-item.c,v 1.9 2000/02/28 04:59:15 trow Exp $ */
 
 /*
  * guppi-canvas-item.c
@@ -303,6 +303,16 @@ guppi_canvas_item_class_init(GuppiCanvasItemClass* klass)
 static void
 guppi_canvas_item_init(GuppiCanvasItem* gci)
 {
+#ifdef OLD_EVENT_HANDLER
+  static void guppi_canvas_item_event_dispatcher(GuppiCanvasItem*,
+						 GdkEvent*, gpointer);
+
+  gtk_signal_connect(GTK_OBJECT(gci),
+		     "event",
+		     GTK_SIGNAL_FUNC(guppi_canvas_item_event_dispatcher),
+		     NULL);
+#endif
+
   gci->x_transform  = transform_new();
   gci->y_transform  = transform_new();
 
@@ -559,6 +569,15 @@ guppi_canvas_item_recenter_around_point(GuppiCanvasItem* gci,
   
 }
 
+void
+guppi_canvas_item_translate(GuppiCanvasItem* gci, double dx, double dy)
+{
+  g_return_if_fail(gci != NULL);
+  guppi_canvas_item_set_scales(gci,
+			       gci->x0 + dx, gci->y0 + dy,
+			       gci->x1 + dx, gci->y1 + dy);
+}
+
 /*****************************************************************************/
 
 /*
@@ -752,8 +771,10 @@ guppi_canvas_item_plot2pixel(const GuppiCanvasItem* gci,
 {
   g_return_if_fail(gci != NULL);
 
-  *cx = transform_plot2pixel(gci->x_transform, x);
-  *cy = transform_plot2pixel(gci->y_transform, y);
+  if (cx)
+    *cx = transform_plot2pixel(gci->x_transform, x);
+  if (cy)
+    *cy = transform_plot2pixel(gci->y_transform, y);
 }
 
 void
@@ -763,8 +784,10 @@ guppi_canvas_item_pixel2plot(const GuppiCanvasItem* gci,
 {
   g_return_if_fail(gci != NULL);
   
-  *x = transform_pixel2plot(gci->x_transform, cx);
-  *y = transform_pixel2plot(gci->y_transform, cy);
+  if (x)
+    *x = transform_pixel2plot(gci->x_transform, cx);
+  if (y)
+    *y = transform_pixel2plot(gci->y_transform, cy);
 }
 
 void
@@ -776,7 +799,6 @@ guppi_canvas_item_world2plot(const GuppiCanvasItem* gci,
 
   g_return_if_fail(gci != NULL);
 
-
   gnome_canvas_w2c(GNOME_CANVAS_ITEM(gci)->canvas, wx, wy, &cx, &cy);
   guppi_canvas_item_pixel2plot(gci, cx, cy, x, y);
 }
@@ -831,6 +853,8 @@ guppi_canvas_item_request_update(GuppiCanvasItem* gci)
   gnome_canvas_item_request_update(GNOME_CANVAS_ITEM(gci));
 }
 
-/* $Id: guppi-canvas-item.c,v 1.7 2000/02/10 02:05:31 trow Exp $ */
+/***************************************************************************/
+
+/* $Id: guppi-canvas-item.c,v 1.9 2000/02/28 04:59:15 trow Exp $ */
 
 
