@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-canvas-item.h,v 1.5 2000/02/06 03:14:54 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.7 2000/02/28 04:59:15 trow Exp $ */
 
 /*
  * guppi-canvas-item.h
@@ -60,6 +60,9 @@ struct _GuppiCanvasItem {
   guint x_bnd_sh, y_bnd_sh;
 
   GuppiItemState* state;
+
+  /* A cop-out to avoid circular dependencies. */
+  gpointer active_tool;
 };
 
 struct _GuppiCanvasItemClass {
@@ -69,7 +72,6 @@ struct _GuppiCanvasItemClass {
   void (*rescaled)(GnomeCanvasItem*, double x0, double y0, double x1, double y1);
   void (*rescaled_x)(GnomeCanvasItem*, double x0, double x1);
   void (*rescaled_y)(GnomeCanvasItem*, double y0, double y1);
-  
 };
 
 #define GUPPI_TYPE_CANVAS_ITEM (guppi_canvas_item_get_type())
@@ -104,6 +106,7 @@ void guppi_canvas_item_rescale_around_point(GuppiCanvasItem*,
 					    double factor);
 void guppi_canvas_item_recenter_around_point(GuppiCanvasItem*,
 					     double x, double y);
+void guppi_canvas_item_translate(GuppiCanvasItem*, double dx, double dy);
 
 void guppi_canvas_item_set_x_bounder(GuppiCanvasItem*, GuppiBounder*);
 void guppi_canvas_item_set_y_bounder(GuppiCanvasItem*, GuppiBounder*);
@@ -136,4 +139,4 @@ void guppi_canvas_item_request_update(GuppiCanvasItem*);
 
 #endif /* _INC_GUPPI_CANVAS_ITEM_H */
 
-/* $Id: guppi-canvas-item.h,v 1.5 2000/02/06 03:14:54 trow Exp $ */
+/* $Id: guppi-canvas-item.h,v 1.7 2000/02/28 04:59:15 trow Exp $ */
