@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-element.c,v 1.4 2000/02/18 06:49:40 trow Exp $ */
+/* $Id: guppi-plot-element.c,v 1.5 2000/02/28 04:56:46 trow Exp $ */
 
 /*
  * guppi-plot-element.c
@@ -142,6 +142,26 @@ guppi_plot_element_class_init(GuppiPlotElementClass* klass)
   klass->make_canvas_item = NULL;
   klass->make_state_widget = NULL;
 
+  klass->default_toolkit = guppi_plot_toolkit_new();
+  guppi_plot_toolkit_set_button_tool(klass->default_toolkit,
+				     1, 0,
+				     guppi_plot_tool_new_rescale(0.90));
+
+  guppi_plot_toolkit_set_button_tool(klass->default_toolkit,
+				     2, 0,
+				     guppi_plot_tool_new_drag());
+
+  guppi_plot_toolkit_set_button_tool(klass->default_toolkit,
+				     3, 0,
+				     guppi_plot_tool_new_rescale(1/0.90));
+  
+  guppi_plot_toolkit_set_button_tool(klass->default_toolkit,
+				     1, GDK_SHIFT_MASK,
+				     guppi_plot_tool_new_reframe());
+
+  guppi_plot_toolkit_set_button_tool(klass->default_toolkit,
+				     2, GDK_SHIFT_MASK | GDK_CONTROL_MASK,
+				     guppi_plot_tool_new_recenter());
 }
 
 static void
@@ -221,12 +241,170 @@ guppi_plot_element_set_label(GuppiPlotElement* gpe, const gchar* label)
   gtk_signal_emit(GTK_OBJECT(gpe), gpe_signals[CHANGED_LABEL]);
 }
 
+/*****************************************************************************/
+
+static gint
+tool_repeat_handler(gpointer data)
+{
+  GuppiPlotTool* tool = GUPPI_PLOT_TOOL(data);
+  (tool->repeat)(tool, tool->canvas_item);
+  return TRUE;
+}
+
+static gint
+event_dispatcher(GuppiCanvasItem* gci, GdkEvent* ev, GuppiPlotElement* elem)
+{
+  GuppiPlotToolkit* tk = NULL;
+  GuppiPlotTool* tool;
+  double x, y;
+
+  tool = GUPPI_PLOT_TOOL0(gci->active_tool);
+
+  if (ev->type == GDK_BUTTON_PRESS && tool == NULL) {
+
+    tk = elem->local_toolkit;
+    if (tk == NULL) 
+      tk = GUPPI_PLOT_ELEMENT_CLASS(GTK_OBJECT(elem)->klass)->default_toolkit;
+    if (tk == NULL)
+      return FALSE;
+
+    tool = guppi_plot_toolkit_get_button_tool(tk,
+					      ev->button.button,
+					      ev->button.state);
+    gci->active_tool = tool;
+
+    if (tool) {
+      tool->canvas_item = gci;
+
+      tool->raw_x = tool->raw_start_x = ev->button.x;
+      tool->raw_y = tool->raw_start_y = ev->button.y;
+
+      guppi_canvas_item_world2plot(gci, ev->button.x, ev->button.y, &x, &y);
+
+      tool->start_x = tool->x = x;
+      tool->start_y = tool->y = y;
+
+      if (tool->first)
+	(tool->first)(tool, gci);
+
+      if (tool->repeating && tool->repeat)
+	tool->repeater_tag = gtk_timeout_add(tool->repeat_interval,
+					     tool_repeat_handler,
+					     tool);
+
+      if (tool->cue_type == GPTPC_FRAME) {
+	tool->cue_item =
+	  gnome_canvas_item_new(gnome_canvas_root(GNOME_CANVAS_ITEM(gci)->canvas),
+				gnome_canvas_rect_get_type(),
+				"outline_color", "black",
+				"fill_color_rgba", tool->cue_fill_color,
+				"width_pixels", (guint)1,
+				"x1", tool->raw_start_x,
+				"y1", tool->raw_start_y,
+				"x2", tool->raw_start_x,
+				"y2", tool->raw_start_y,
+				NULL);
+
+      } else if (tool->cue_type == GPTPC_CIRCLE) {
+	tool->cue_item =
+	  gnome_canvas_item_new(gnome_canvas_root(GNOME_CANVAS_ITEM(gci)->canvas),
+				gnome_canvas_ellipse_get_type(),
+				"outline_color", "black",
+				"fill_color_rgba", tool->cue_fill_color,
+				"width_pixels", (guint)1,
+				"x1", tool->raw_start_x - tool->cue_arg,
+				"y1", tool->raw_start_y - tool->cue_arg,
+				"x2", tool->raw_start_x + tool->cue_arg,
+				"y2", tool->raw_start_y + tool->cue_arg,
+				NULL);
+      }
+
+    }
+
+    return tool != NULL;
+
+  } else if (ev->type == GDK_BUTTON_RELEASE && tool != NULL) {
+
+    if (tool->cue_item) {
+      gnome_canvas_item_hide(tool->cue_item);
+      gtk_object_destroy(GTK_OBJECT(tool->cue_item));
+      tool->cue_item = NULL;
+    }
+
+    if (tool->repeating)
+      gtk_timeout_remove(tool->repeater_tag);
+
+    if (tool->last) {
+      tool->raw_prev_x = tool->raw_x;
+      tool->raw_prev_y = tool->raw_y;
+      tool->prev_x = tool->x;
+      tool->prev_y = tool->y;
+      guppi_canvas_item_world2plot(gci, ev->button.x, ev->button.y, &x, &y);
+      tool->raw_x = ev->button.x;
+      tool->raw_y = ev->button.y;
+      tool->x = x;
+      tool->y = y;
+      (tool->last)(tool, gci);
+    }
+
+    gci->active_tool = NULL;
+
+    return TRUE;
+
+  } else if (ev->type == GDK_MOTION_NOTIFY && tool != NULL &&
+	     (tool->tracks_motion || tool->middle || tool->cue_item != NULL)) {
+
+    tool->raw_prev_x = tool->raw_x;
+    tool->raw_prev_y = tool->raw_y;
+    tool->prev_x = tool->x;
+    tool->prev_y = tool->y;
+    guppi_canvas_item_world2plot(gci, ev->motion.x, ev->motion.y, &x, &y);
+    tool->raw_x = ev->motion.x;
+    tool->raw_y = ev->motion.y;
+
+    if (tool->cue_item) {
+      if (tool->cue_type == GPTPC_FRAME) {
+
+	gnome_canvas_item_set(tool->cue_item,
+			      "x1", MIN(tool->raw_start_x, tool->raw_x),
+			      "y1", MIN(tool->raw_start_y, tool->raw_y),
+			      "x2", MAX(tool->raw_start_x, tool->raw_x),
+			      "y2", MAX(tool->raw_start_y, tool->raw_y),
+			      NULL);
+      } else if (tool->cue_type == GPTPC_CIRCLE) {
+
+	gnome_canvas_item_set(tool->cue_item,
+			      "x1", tool->raw_x - tool->cue_arg,
+			      "y1", tool->raw_y - tool->cue_arg,
+			      "x2", tool->raw_x + tool->cue_arg,
+			      "y2", tool->raw_y + tool->cue_arg,
+			      NULL);
+      } else {
+	g_assert_not_reached();
+      }
+    }
+			    
+
+    tool->x = x;
+    tool->y = y;
+    if (tool->middle) 
+      (tool->middle)(tool, gci);
+    if (ev->motion.is_hint)
+      gdk_window_get_pointer(ev->motion.window, NULL, NULL, NULL);
+    
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
 GuppiCanvasItem*
 guppi_plot_element_make_canvas_item(GuppiPlotElement* gpe,
 				    GnomeCanvas* canv,
 				    double x1, double y1,
 				    double x2, double y2)
 {
+  GuppiCanvasItem* gci;
   GuppiCanvasItem* (*fn)(GuppiPlotElement*, GnomeCanvas*, double, double, double, double);
 
   g_return_val_if_fail(gpe != NULL, NULL);
@@ -238,7 +416,14 @@ guppi_plot_element_make_canvas_item(GuppiPlotElement* gpe,
     return NULL;
   } 
 
-  return fn(gpe, canv, x1, y1, x2, y2);
+  gci = fn(gpe, canv, x1, y1, x2, y2);
+
+  gtk_signal_connect(GTK_OBJECT(gci),
+		     "event",
+		     GTK_SIGNAL_FUNC(event_dispatcher),
+		     gpe);
+
+  return gci;
 }
 
 GtkWidget*
@@ -351,4 +536,4 @@ guppi_plot_element_edit(GuppiPlotElement* gpe)
 
 
 
-/* $Id: guppi-plot-element.c,v 1.4 2000/02/18 06:49:40 trow Exp $ */
+/* $Id: guppi-plot-element.c,v 1.5 2000/02/28 04:56:46 trow Exp $ */
