@@ -1,5 +1,5 @@
 /* This is -*- C -*- */
-/* $Id: guppi-plot-element.h,v 1.3 2000/02/18 06:49:40 trow Exp $ */
+/* $Id: guppi-plot-element.h,v 1.4 2000/02/28 04:56:46 trow Exp $ */
 
 /*
  * guppi-plot-element.h
@@ -30,7 +30,8 @@
 
 #include <config.h>
 #include <gnome.h>
-#include <guppi-canvas-item.h>
+#include "guppi-canvas-item.h"
+#include "guppi-plot-toolkit.h"
 
 typedef struct _GuppiPlotElement GuppiPlotElement;
 typedef struct _GuppiPlotElementClass GuppiPlotElementClass;
@@ -40,11 +41,15 @@ struct _GuppiPlotElement {
 
   gboolean visible;
   gchar* label;
+
+  GuppiPlotToolkit* local_toolkit;
 };
 
 struct _GuppiPlotElementClass {
   GtkObjectClass parent_class;
 
+  GuppiPlotToolkit* default_toolkit;
+
   /* virtual data/functions */
   const gchar* type_name;
   GuppiCanvasItem* (*make_canvas_item)(GuppiPlotElement*,
@@ -100,4 +105,4 @@ void guppi_plot_element_edit(GuppiPlotElement*);
 
 #endif /* _INC_GUPPI_PLOT_ELEMENT_H */
 
-/* $Id: guppi-plot-element.h,v 1.3 2000/02/18 06:49:40 trow Exp $ */
+/* $Id: guppi-plot-element.h,v 1.4 2000/02/28 04:56:46 trow Exp $ */
