@@ -1,4 +1,4 @@
-/* $Id: guppi-paths.c,v 1.2 2000/01/17 21:38:34 trow Exp $ */
+/* $Id: guppi-paths.c,v 1.3 2000/02/16 22:47:53 trow Exp $ */
 
 /*
  * guppi-paths.c
@@ -72,6 +72,13 @@ guppi_glade_path(const gchar* filename)
   resolved = g_strdup_printf("../../plug-ins/scatter/%s", filename);
   if (g_file_exists(resolved))
     return resolved;
+
+  g_free(resolved);
+  resolved = g_strdup_printf("../../plug-ins/import-delimited/%s", filename);
+  if (g_file_exists(resolved))
+    return resolved;
+
+  /* End badness */
   
   g_free(resolved);
   g_warning("Couldn't find \"%s\"", filename);
@@ -114,4 +121,4 @@ gnome_guile_repl_path(void)
 
 
 
-/* $Id: guppi-paths.c,v 1.2 2000/01/17 21:38:34 trow Exp $ */
+/* $Id: guppi-paths.c,v 1.3 2000/02/16 22:47:53 trow Exp $ */
